retrieve the coefficients under given tuning parameter
# S3 method for fpen
coef(object, ...)A vector of estimated parameters.
Object with class "fpen", generated from frailtyMMpen.
Ignored
Without given a specific tune value, the coefficients with minimum BIC is returned. If tune=a,
the coefficient is computed using linear interpolation of the result from the coefficients estimated from the run of regularization path.
Thus, a should between the minimum and maximum value of the tuning parameter sequences used for the model fitting.