print.fpen: print a penalized regression object
Description
Print the summary of a non-penalized regression fitted by any model with function frailtyMMpen.
The first column is the tuning parameter sequence, the second column is the degree of freedom and the third column is the BIC.
Usage
# S3 method for fpen
print(x, ...)
Value
No return value, called to print the summary for penalized regression.
Arguments
- x
Object with class "fpen" fitted by function frailtyMMpen.
- ...
Ignored